from setuptools import setup

setup(
	name="porterdb",
	version="0.0.1",
	description="a simple document based database manager",
	url="https://github.com/wrecodde/porterdb",
	author="Deji Joseph",
	author_email="wrecodde@gmail.com",
	license="MIT",
        packages=["porterdb"],
        long_description=open("README.txt").read()
)
